@@ -5,6 +5,8 @@ from ...conf.rwd.Website import opera_browser_conf
 from selenium.webdriver.chrome.options import Options
 import sys
 from selenium import webdriver
+from selenium.webdriver.chrome.service import Service as ChromeService
+from webdriver_manager.chrome import ChromeDriverManager
 
 
 class LocalBrowsers():
@@ -27,7 +29,7 @@ class LocalBrowsers():
     @staticmethod
     def chrome_local():
         """Get webdriver for chrome."""
-        local_driver = webdriver.Chrome()
+        local_driver = webdriver.Chrome(service=ChromeService(ChromeDriverManager().install()))
         # local_driver = webdriver.Chrome('./chromedriver/v92/chromedriver')
         return local_driver
 
