@@ -1,8 +1,10 @@
 """
 Class to hold miscellaneous but useful decorators for our framework
 """
-import pytest
+
 from inspect import getfullargspec
+import traceback
+
 
 class Wrapit():
     "Wrapit class to hold decorator functions"
@@ -41,33 +43,38 @@ class Wrapit():
             # If return True, only take screenshot if option -screenshot all
             # If return False, take screenshot for both -screenshot all/failonly
             # If not return boolean, skip screenshot
-            # if args[0].screenshot == 'all':
-            #     screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
-            #     args[0].screenshot_counter += 1
-            #     args[0].save_screenshot(screenshot_name)
-            # elif args[0].screenshot == 'failonly' and result is False:
-            #     screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
-            #     args[0].screenshot_counter += 1
-            #     args[0].save_screenshot(screenshot_name)
-
-            if not result:
-                # filename = f"{func.__name__}.png"
+            if args[0].screenshot == 'all':
+                screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
+                args[0].screenshot_counter += 1
+                args[0].save_screenshot(screenshot_name)
+            elif args[0].screenshot == 'failonly' and result is False:
                 screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
                 args[0].screenshot_counter += 1
                 args[0].save_screenshot(screenshot_name)
-                # code to take the screenshot
-                # base_page.save_screenshot(screenshot_name)
-                # ...
-                request = getattr(func, "request", None)
-                if request:
-                    html_report = request.config.pluginmanager.get_plugin("html")
-                    if html_report:
-                        html_report.attach_file(screenshot_name)
-
             return result
 
         return wrapper
 
+    # def _logging_decorator(func):
+    #
+    #     def wrapper(test_obj, product, cases, extra, testID, *args, **kwargs):
+    #         try:
+    #             result = func(test_obj, product, cases, extra, testID, *args, **kwargs)
+    #             globals()['gif_file'] = test_obj.write_test_summary()
+    #         except Exception as e:
+    #             print("Exception when trying to run test: %s" % __file__)
+    #             print("Python says:%s" % str(e))
+    #             test_obj.write(traceback.format_exc())
+    #
+    #             # Detail print in last line
+    #             with open(test_obj.logs_parent_dir + test_obj.log_name, "a") as logfile:
+    #                 traceback.print_exc(file=logfile)
+    #             globals()['gif_file'] = test_obj.write_test_summary()
+    #             raise
+    #         return result
+    #
+    #     return wrapper
+
     def _check_browser_console_log(func):
         "Decorator to check the browser's console log for errors"
 
@@ -99,6 +106,7 @@ class Wrapit():
 
         return wrapper
 
+
         # def _screencap(func):
         #     "Decorator for taking screencap for test"
         #
@@ -108,7 +116,7 @@ class Wrapit():
         #         result = "this is _screencap"
         #         print("%s is running" % func.__name__)
 
-        return wrapper
+        # return wrapper
 
     _exceptionHandler = staticmethod(_exceptionHandler)
     _screenshot = staticmethod(_screenshot)
